import TestMode from '@thats/testing/_/TestMode'
import fs from 'fs'
import NodeEnvironment from 'jest-environment-node'
import os from 'os'
import path from 'path'
import puppeteer from 'puppeteer'

const DIR = path.join(os.tmpdir(), 'jest_puppeteer_global_setup')

export class PuppeteerEnvironment extends NodeEnvironment {
	constructor(config, _context) {
		super(config, _context)
		this.global['__TESTMODE__'] = process.env.TEST_MODE ?? TestMode.ALL
	}

	async setup() {
		await super.setup()

		// get the wsEndpoint
		const wsEndpoint = await fs.readFileSync(path.join(DIR, 'wsEndpoint'), 'utf8')
		if (!wsEndpoint) {
			throw new Error('wsEndpoint not found')
		}

		// connect to puppeteer
		this.global['__broser'] = await puppeteer.connect({
			browserWSEndpoint: wsEndpoint,
		})
	}

	async teardown() {
		await super.teardown()
	}

	getVmContext() {
		return super.getVmContext()
	}
}
export default PuppeteerEnvironment
