import fs from 'fs'
import os from 'os'
import path from 'path'
import puppeteer from 'puppeteer'

const DIR = path.join(os.tmpdir(), 'jest_puppeteer_global_setup')

export async function e2eSetup(
	appUrl: string,
	loginEmail: string,
	loginPword: string
): Promise<void> {
	process.env.WEB_TEST_LOGIN_EMAIL = loginEmail
	process.env.WEB_TEST_LOGIN_PWORD = loginPword
	process.env.WEB_TEST_APP_URL = appUrl

	globalThis.__browser = await puppeteer.launch({
		ignoreHTTPSErrors: true,
		args: [
			'--proxy-bypass-list=*',
			'--disable-gpu',
			'--disable-dev-shm-usage',
			'--disable-setuid-sandbox',
			'--no-first-run',
			'--no-sandbox',
			'--no-zygote',
			'--single-process',
			'--ignore-certificate-errors',
			'--ignore-certificate-errors-spki-list',
			'--enable-features=NetworkService',
		],
	})

	// use the file system to expose the wsEndpoint for TestEnvironments
	await fs.mkdirSync(DIR, { recursive: true })
	await fs.writeFileSync(path.join(DIR, 'wsEndpoint'), globalThis.__browser.wsEndpoint())
}
export default e2eSetup
